Struct ACL

#[repr(C, packed(1))]
pub struct ACL { pub revision: ntfs_u8, pub alignment1: ntfs_u8, pub size: le16, pub ace_count: le16, pub alignment2: le16, }
struct ACL - An ACL is an access-control list (ACL).

An ACL starts with an ACL header structure, which specifies the size of the ACL and the number of ACEs it contains. The ACL header is followed by zero or more access control entries (ACEs). The ACL as well as each ACE are aligned on 4-byte boundaries.

Fields

revision: ntfs_u8alignment1: ntfs_u8size: le16ace_count: le16alignment2: le16