Struct GUID

#[repr(C, packed(1))]
pub struct GUID { pub data1: le32, pub data2: le16, pub data3: le16, pub data4: [ntfs_u8; 8], }
struct GUID - GUID structures store globally unique identifiers (GUID).

A GUID is a 128-bit value consisting of one group of eight hexadecimal digits, followed by three groups of four hexadecimal digits each, followed by one group of twelve hexadecimal digits. GUIDs are Microsoft’s implementation of the distributed computing environment (DCE) universally unique identifier (UUID).

Example of a GUID: 1F010768-5A73-BC91-0010-A52216A7227B

Fields

data1: le32data2: le16data3: le16data4: [ntfs_u8; 8]