#[repr(C, packed(1))]pub struct INDEX_ROOT {
pub type_: ATTR_TYPES,
pub collation_rule: COLLATION_RULES,
pub index_block_size: le32,
pub clusters_per_index_block: s8,
pub reserved: [ntfs_u8; 3],
pub index: INDEX_HEADER,
}Expand description
struct INDEX_ROOT - Attribute: Index root (0x90).
NOTE: Always resident.
This is followed by a sequence of index entries (INDEX_ENTRY structures) as described by the index header.
When a directory is small enough to fit inside the index root then this is the only attribute describing the directory. When the directory is too large to fit in the index root, on the other hand, two additional attributes are present: an index allocation attribute, containing sub-nodes of the B+ directory tree (see below), and a bitmap attribute, describing which virtual cluster numbers (vcns) in the index allocation attribute are in use by an index block.
NOTE: The root directory (FILE_root) contains an entry for itself. Other directories do not contain entries for themselves, though.
Fields
type_: ATTR_TYPEScollation_rule: COLLATION_RULESindex_block_size: le32clusters_per_index_block: s8reserved: [ntfs_u8; 3]index: INDEX_HEADERTrait Implementations
Sourceimpl Clone for INDEX_ROOT
impl Clone for INDEX_ROOT
Sourcefn clone(&self) -> INDEX_ROOT
fn clone(&self) -> INDEX_ROOT
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more