#[repr(C, packed(1))]pub struct SID {
pub revision: ntfs_u8,
pub sub_authority_count: ntfs_u8,
pub identifier_authority: SID_IDENTIFIER_AUTHORITY,
pub sub_authority: [le32; 1],
}Expand description
struct SID -
The SID structure is a variable-length structure used to uniquely identify users or groups. SID stands for security identifier.
The standard textual representation of the SID is of the form: S-R-I-S-S… Where:
- The first “S” is the literal character ‘S’ identifying the following digits as a SID.
- R is the revision level of the SID expressed as a sequence of digits in decimal.
- I is the 48-bit identifier_authority, expressed as digits in decimal, if I < 2^32, or hexadecimal prefixed by “0x”, if I >= 2^32.
- S… is one or more sub_authority values, expressed as digits in decimal.
Example SID; the domain-relative SID of the local Administrators group on Windows NT/2k: S-1-5-32-544 This translates to a SID with: revision = 1, sub_authority_count = 2, identifier_authority = {0,0,0,0,0,5}, // SECURITY_NT_AUTHORITY sub_authority[0] = 32, // SECURITY_BUILTIN_DOMAIN_RID sub_authority[1] = 544 // DOMAIN_ALIAS_RID_ADMINS
Fields
revision: ntfs_u8Trait Implementations